Predefined point types commonly used in ROS.
Structs
- PointXYZ
- 3D point with x, y, z coordinates, commonly used in ROS with PCL.
- PointXYZI
- 3D point with x, y, z coordinates and an intensity value, commonly used in ROS with PCL.
- PointXYZI
Normal - 3D point with x, y, z coordinates, an intensity value and a normal vector, commonly used in ROS with PCL.
- PointXYZL
- 3D point with x, y, z coordinates and a label, commonly used in ROS with PCL.
- PointXYZ
Normal - 3D point with x, y, z coordinates and a normal vector, commonly used in ROS with PCL.
- PointXYZRGB
- 3D point with x, y, z coordinates and an RGB color value, commonly used in ROS with PCL.
- PointXYZRGBA
- 3D point with x, y, z coordinates and an RGBA color value, commonly used in ROS with PCL. The alpha channel is commonly used as padding but this crate uses every channel and no padding.
- PointXYZRGBL
- 3D point with x, y, z coordinates and a label, commonly used in ROS with PCL.
- PointXYZRGB
Normal - 3D point with x, y, z coordinates, an RGB color value and a normal vector, commonly used in ROS with PCL.
Unions
- RGB
- Packed RGB color encoding as used in ROS tools.